@@ -1,4 +1,4 @@
-//$Id: checkbox-canvas.cc,v 1.12 2001/10/18 19:08:51 cactus Exp $ -*- c++ -*-
+//$Id: checkbox-canvas.cc,v 1.14 2001/10/30 17:34:48 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,7 +21,6 @@
 #include "form-editor.h"
 
 #include <gnome--/canvas-polygon.h>
-#include <gnome--/canvas-rect.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk-pixbuf/gnome-canvas-pixbuf.h>
 
@@ -60,17 +59,7 @@ void CheckboxCanvasItem::update ()
     /* A Polygon is used instead of a Rectangle to get mouse events
      * inside the "hollow" area
      */
-    Gnome::CanvasPoints frame_points;
-    using namespace Gnome::Art;
-    
-    frame_points.push_back (Point (x1, y1));
-    frame_points.push_back (Point (x2, y1));
-    frame_points.push_back (Point (x2, y2));
-    frame_points.push_back (Point (x1, y2));
-    frame_points.push_back (Point (x1, y1));
-
-    Gnome::CanvasPolygon *item = new Gnome::CanvasPolygon (*group, frame_points);
-    item->set_width_units (0);
+    FormEditor::draw_rectangle (*group, x1, y1, x2, y2);
     
     int text_x = x1 + 17;
     int text_y = y1 + height / 2 - 2;
@@ -87,12 +76,8 @@ void CheckboxCanvasItem::update ()
 	else
 	    pixbuf = gdk_pixbuf_new_from_xpm_data ((const char**)checkbox_canvas_off_disabled_xpm);
 
-    gnome_canvas_item_new (group->gtkobj (),
-			   gnome_canvas_pixbuf_get_type (),
-			   "pixbuf", pixbuf,
-			   "x", (double)widget->x + 2,
-			   "y", (double)widget->y + 1,
-			   0);
+    FormEditor::draw_pixbuf (*group, pixbuf,
+			     widget->x + 2, widget->y + 1);
     gdk_pixbuf_unref (pixbuf);
 
     if (width > 18)
@@ -102,7 +87,7 @@ void CheckboxCanvasItem::update ()
 		   text_x, text_y,
 		   widget->usable,
 		   GTK_ANCHOR_WEST,
-		   width - 18, height);
+		   width - 16, height);
     }
     
     set_canvas_item (group);
