@@ -1,4 +1,4 @@
-//$Id: list-prop.cc,v 1.8 2001/11/03 19:18:31 cactus Exp $ -*- c++ -*-
+//$Id: list-prop.cc,v 1.9 2001/11/15 20:21:59 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -71,7 +71,7 @@ ListProperties::ListProperties (List *res)
     WidgetProperties::add_position_controls (res, *proptable);
 
     /* Width */
-    control = new GUI::PosEntry (res->width);
+    control = new GUI::SizeEntry (res->width);
     control = new GUI::AutoToggle (*manage (control), res->manual_width);
     proptable->add (_("_Width:"), *manage (control),
 		    _("Horizontal size of the widget "
