@@ -1,4 +1,4 @@
-//$Id: form-win.cc,v 1.35 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
+//$Id: form-win.cc,v 1.36 2001/11/18 10:59:50 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -50,7 +50,7 @@ FormWindow::FormWindow (Form *res_):
     canvas_overlay (0),
     palette_selection (Widgets::WIDGET_NONE)
 {
-    gui = glade_xml_new (GLADEDIR "/guikachu.glade", 0);
+    gui = glade_xml_new (GLADEDIR "/guikachu.glade", "res_form");
 
     using namespace Gtk;
     using namespace SigC;
